import os

from copy import deepcopy

from charmhelpers.core.hookenv import (
    log,
)

from charmhelpers.core.templating import render

from grafana_contexts import (
    GrafanaContext,
)

TEMPLATES = 'templates/'

BASE_PACKAGES = [
    'grafana',
]

GRAFANA_CONF_DIR = "/etc/grafana"
GRAFANA_CONF = '%s/grafana.ini' % GRAFANA_CONF_DIR


BASE_RESOURCE_MAP = {
    GRAFANA_CONF: {
        'services': ['grafana-server'],
        'contexts': [GrafanaContext()]
    },
}


def juju_log(msg):
    log('[grafana] %s' % msg)


def resource_map():
    '''
    Dynamically generate a map of resources that will be managed for a single
    hook execution.
    '''
    resource_map = deepcopy(BASE_RESOURCE_MAP)

    return resource_map


def restart_map():
    '''
    Constructs a restart map based on charm config settings and relation
    state.
    '''
    return {k: v['services'] for k, v in resource_map().iteritems()}


def services():
    ''' Returns a list of services associate with this charm '''
    _services = []
    for v in restart_map().values():
        _services = _services + v
    return list(set(_services))


def write_conf(targets=None):
    '''
    Renders templates
    '''
    for cfg, d in resource_map().iteritems():
        tmpl = '%s.tmpl' % os.path.basename(cfg)
        ctxt_dict = {}
        for ctxt_obj in d['contexts']:
            ctxt_dict.update(ctxt_obj())
        render(tmpl, cfg, ctxt_dict, owner='root', group='grafana',
               perms=0o640, templates_dir=TEMPLATES)


def determine_packages():
    packages = [] + BASE_PACKAGES

    return packages
